summaryrefslogtreecommitdiffstats
path: root/kresources/groupwise/kabc_resourcegroupwise.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/groupwise/kabc_resourcegroupwise.cpp')
-rw-r--r--kresources/groupwise/kabc_resourcegroupwise.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kresources/groupwise/kabc_resourcegroupwise.cpp b/kresources/groupwise/kabc_resourcegroupwise.cpp
index 9aa33ac7..7c87508e 100644
--- a/kresources/groupwise/kabc_resourcegroupwise.cpp
+++ b/kresources/groupwise/kabc_resourcegroupwise.cpp
@@ -347,7 +347,7 @@ void ResourceGroupwise::fetchAddressBooks( const BookType bookType )
}
mJob = KIO::get( url, false, false ); // TODO: make the GW jobs call finished if the URL
// contains no address book IDs
kdDebug() << " Job address: " << mJob << endl;
connect( mJob, TQT_SIGNAL( data( KIO::Job *, const TQByteArray & ) ),
TQT_SLOT( slotReadJobData( KIO::Job *, const TQByteArray & ) ) );
@@ -558,7 +558,7 @@ void ResourceGroupwise::slotUpdateJobData( KIO::Job *job, const TQByteArray &dat
if ( !local.isEmpty() )
{
idMapper().removeRemoteId( remote );
- KABC::Addressee addrToDelete = findByUid( local );
+ KABC::Addressee addrToDelete = tqfindByUid( local );
removeAddressee( addrToDelete );
}
}
@@ -708,7 +708,7 @@ KURL ResourceGroupwise::createAccessUrl( BookType bookType, AccessMode mode, uns
if ( mode == Update && lastSequenceNumber > 0 && lastPORebuildTime > 0 )
{
- query += TQString::fromLatin1( "&update=true&lastSeqNo=%1&PORebuildTime=%2" ).arg( lastSequenceNumber ).arg( lastPORebuildTime );;
+ query += TQString::tqfromLatin1( "&update=true&lastSeqNo=%1&PORebuildTime=%2" ).arg( lastSequenceNumber ).arg( lastPORebuildTime );;
}
url.setQuery( query );
return url;
@@ -732,9 +732,9 @@ void ResourceGroupwise::storeDeltaInfo()
bool ResourceGroupwise::appIsWhiteListedForSAB()
{
- if ( !mPrefs->systemAddressBookWhiteList().contains( qApp->argv()[ 0 ] ) )
+ if ( !mPrefs->systemAddressBookWhiteList().tqcontains( tqApp->argv()[ 0 ] ) )
{
- kdDebug() << "Application " << qApp->argv()[ 0 ] << " is _blacklisted_ to load the SAB" << endl;
+ kdDebug() << "Application " << tqApp->argv()[ 0 ] << " is _blacklisted_ to load the SAB" << endl;
return false;
}
return true;
@@ -347,7 +347,7 @@ void ResourceGroupwise::fetchAddressBooks( const BookType bookType )
}
mJob = KIO::get( url, false, false ); // TODO: make the GW jobs call finished if the URL
- // contains no address book IDs
+ // tqcontains no address book IDs
kdDebug() << " Job address: " << mJob << endl;
connect( mJob, TQT_SIGNAL( data( KIO::Job *, const TQByteArray & ) ),